<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.AI.Actions.Hosting

Windows Runtime (WinRT) APIs for for the `Windows.AI.Actions.Hosting` namespace.

This package provides the `winrt.windows.ai.actions.hosting` module.
